==> graylog2-server-4.1.1-sources.jar: org/graylog/plugins/views/migrations/V20191203120602_MigrateSavedSearchesToViewsSupport/view/TimeRange.java <==
/*
 * Copyright (C) 2020 Graylog, Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the Server Side Public License, version 1,
 * as published by MongoDB, Inc.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * Server Side Public License for more details.
 *
 * You should have received a copy of the Server Side Public License
 * along with this program. If not, see
 * <http://www.mongodb.com/licensing/server-side-public-license>.
 */
package org.graylog.plugins.views.migrations.V20191203120602_MigrateSavedSearchesToViewsSupport.view;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;

@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "type", visible = true)
@JsonSubTypes({
        @JsonSubTypes.Type(value = AbsoluteRange.class, name = TimeRange.ABSOLUTE),
        @JsonSubTypes.Type(value = KeywordRange.class, name = TimeRange.KEYWORD),
        @JsonSubTypes.Type(value = RelativeRange.class, name = TimeRange.RELATIVE)
})
public abstract class TimeRange {
    public static final String ABSOLUTE = "absolute";
    public static final String KEYWORD = "keyword";
    public static final String RELATIVE = "relative";
    @JsonProperty
    public abstract String type();
}

==> graylog2-server-5.1.11-sources.jar: org/graylog/plugins/views/migrations/V20191203120602_MigrateSavedSearchesToViewsSupport/view/TimeRange.java <==
/*
 * Copyright (C) 2020 Graylog, Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the Server Side Public License, version 1,
 * as published by MongoDB, Inc.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * Server Side Public License for more details.
 *
 * You should have received a copy of the Server Side Public License
 * along with this program. If not, see
 * <http://www.mongodb.com/licensing/server-side-public-license>.
 */
package org.graylog.plugins.views.migrations.V20191203120602_MigrateSavedSearchesToViewsSupport.view;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;

@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "type", visible = false)
@JsonSubTypes({
        @JsonSubTypes.Type(value = AbsoluteRange.class, name = TimeRange.ABSOLUTE),
        @JsonSubTypes.Type(value = KeywordRange.class, name = TimeRange.KEYWORD),
        @JsonSubTypes.Type(value = RelativeRange.class, name = TimeRange.RELATIVE)
})
public abstract class TimeRange {
    public static final String ABSOLUTE = "absolute";
    public static final String KEYWORD = "keyword";
    public static final String RELATIVE = "relative";
    @JsonProperty
    public abstract String type();
}
